@@ -10,115 +10,7 @@ use Time::HiRes qw(gettimeofday tv_interval);
 use POSIX qw(strftime);
 
 
-our $VERSION = '0.11';
-
-
-# useful defaults Zabbix Constant list:
-
-use constant {
-    Z_AGENT_PORT  => 10050,
-    Z_SERVER_PORT => 10051,
-    Z_SNMP_PORT   => 161,
-
-    # zabbix api constants definitions
-
-    OUTPUT_EXTEND               => 'extend',
-    OUTPUT_REFER                => 'refer',
-    OUTPUT_SHORTEN              => 'shorten',
-    HOST_INTERFACE_SECONDARY    => 0,
-    HOST_INTERFACE_PRIMARY      => 1,
-    HOST_INTERFACE_TYPE_UNKNOWN => 0,
-    HOST_INTERFACE_TYPE_AGENT   => 1,
-    HOST_INTERFACE_TYPE_SNMP    => 2,
-    HOST_INTERFACE_TYPE_IPMI    => 3,
-    HOST_INTERFACE_TYPE_JMX     => 4,
-    HOST_USE_DNS                => 0,
-    HOST_USE_IP                 => 1,
-    HOST_STATUS_ON              => 0,
-    HOST_STATUS_OFF             => 1,
-    ITEM_TYPE_AGENT             => 0,
-    ITEM_TYPE_SNMP1             => 1,
-    ITEM_TYPE_TRAPPER           => 2,
-    ITEM_TYPE_SIMPLE            => 3,
-    ITEM_TYPE_SNMP2             => 4,
-    ITEM_TYPE_INTERN            => 5,
-    ITEM_TYPE_SNMP3             => 6,
-    ITEM_TYPE_AAGENT            => 7,
-
-    # zabbix agent (active)
-
-    ITEM_TYPE_AGGR                  => 8,
-    ITEM_TYPE_HTTP                  => 9,
-    ITEM_TYPE_EXTERN                => 10,
-    ITEM_TYPE_DBMON                 => 11,
-    ITEM_TYPE_IPMI                  => 12,
-    ITEM_TYPE_SSH                   => 13,
-    ITEM_TYPE_TELNET                => 14,
-    ITEM_TYPE_CALC                  => 15,
-    ITEM_TYPE_JMX                   => 16,
-    ITEM_TYPE_SNMPT                 => 17,
-    ITEM_STATUS_ACTIVE              => 0,
-    ITEM_STATUS_DISABLED            => 1,
-    ITEM_STATUS_NOT_SUP             => 3,
-    ITEM_VALUE_FLOAT                => 0,
-    ITEM_VALUE_CHAR                 => 1,
-    ITEM_VALUE_LOG                  => 2,
-    ITEM_VALUE_UINT                 => 3,
-    ITEM_VALUE_TEXT                 => 4,
-    ITEM_DATA_DEC                   => 0,
-    ITEM_DATA_OCT                   => 1,
-    ITEM_DATA_HEX                   => 2,
-    ITEM_DATA_BIN                   => 3,    # same as BOOL-ean
-    ITEM_DATA_BOOL                  => 3,
-    ITEM_DELTA_ASIS                 => 0,
-    ITEM_DELTA_PERSEC               => 1,
-    ITEM_DELTA_CHANGE               => 2,
-    ITEM_SSH_AUTH_PASSWORD          => 0,
-    ITEM_SSH_AUTH_PUBKEY            => 1,
-    ITEM_FLAG_PLAIN                 => 0,
-    ITEM_FLAG_DISCOVERED            => 4,
-    ITEM_SNMP_PRIV_NANP             => 0,
-    ITEM_SNMP_PRIV_ANP              => 1,
-    ITEM_SNMP_PRIV_AP               => 2,
-    TRIGGER_STATUS_ACTIVE           => 0,
-    TRIGGER_STATUS_DISABLED         => 1,
-    TRIGGER_VALUE_OK                => 2,
-    TRIGGER_VALUE_PROBLEM           => 3,
-    TRIGGER_VALUE_ON                => 4,
-    TRIGGER_SEVERITY_UNKN           => 0,
-    TRIGGER_SEVERITY_INFO           => 1,
-    TRIGGER_SEVERITY_WARN           => 2,
-    TRIGGER_SEVERITY_AVRG           => 3,
-    TRIGGER_SEVERITY_HIGH           => 4,
-    TRIGGER_SEVERITY_DISA           => 5,
-    TRIGGER_TYPE_NORMAL             => 0,
-    TRIGGER_TYPE_MULTI              => 1,
-    TRIGGER_FLAG_GOOD               => 0,
-    TRIGGER_FLAG_UNCERTAIN          => 1,
-    TRIGGER_STATUS_ICMPPING_FAIL    => 0,
-    TRIGGER_STATUS_ICMPPING_SUCCESS => 1,
-
-  # http://www.zabbix.com/documentation/2.0/manual/appendix/api/user/definitions
-    USER_TYPE_USER       => 1,
-    USER_TYPE_ADMIN      => 2,
-    USER_TYPE_SUPERADMIN => 3,
-    USER_TYPE_ROOT       => 3,                # same as Super Admin
-    USER_THEME_1         => 'originalblue',
-    USER_THEME_2         => 'darkblue',
-    USER_THEME_3         => 'darkorange',
-
-    # 0 seconds means disabled
-    USER_AUTOLOGIN_DISABLE => 0,
-
-# http://www.zabbix.com/documentation/2.0/manual/appendix/api/usergroup/definitions
-    GROUP_ACCESS_DEFAULT  => 0,
-    GROUP_ACCESS_INTERNAL => 1,
-    GROUP_ACCESS_DISABLED => 2,
-    GROUP_STATUS_ENABLED  => 0,
-    GROUP_STATUS_DISABLED => 1,
-    GROUP_DEBUG_ENABLED   => 1,
-    GROUP_DEBUG_DISABLED  => 0,
-};
+our $VERSION = '0.14';
 
 sub new {
     my $class    = shift;
@@ -148,7 +40,7 @@ sub new {
         Count       => 1,
         Auth        => undef,
         API_URL     => $args->{url},
-        Output      => OUTPUT_EXTEND,
+        Output      => "extend",
         Debug       => $args->{debug} ? 1 : 0,
         Trace       => $args->{trace} ? 1 : 0,
         User        => $args->{username},
@@ -220,9 +112,8 @@ sub debug {
 
 sub auth {
     my $self = shift;
-
     if ( not defined $self->{Auth} ) {
-        $self->{Auth} = '';   
+        $self->{Auth} = ''; 
         my $res = $self->http_request(
             'user', 'login',
             {
@@ -230,7 +121,6 @@ sub auth {
                 password => $self->{Password},
             }
         );
-
         #confess $res->{error}->{data}
         warn "$res->{error}->{data}\nError Code: $res->{error}->{code} 
             \nResponse: $res->{error}->{message}"
@@ -315,7 +205,7 @@ sub http_request {
 
     if ($params) {
         $params->{output} = $self->{Output}
-          if ( reftype($params) eq 'HASH' and not defined $params->{output} );
+          if ( reftype($params) eq 'HASH' and not defined $params->{output} and $object.$op ne "userlogin" );
     }
     else {
         $params = [];
